/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAi for the 3D integration at all eps-orders of the Rest-CA structure. 
 * Example: CAI3EM2t ('CA' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd order, third integration over 't'5 or its rescaled version) 
 * contains various differences of logs of FXi functions evaluated at z=0,c=0,x=0, i.e. with deltas from all +-distributions except the t5/s5 one, multiplied 
 * with the correct XCA functions to arrive at eps^-2. 
 * Starting from eps^-3 (3 deltas) we need 1 eps powers, which we get from XCA1 (which comes with eps^1) and no Logs, or Log^1 terms multiplied with XCA0 (eps^1 from the logs)
 */

#include <3IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

using namespace std;

//third integration is over t5 (s5 after rescaling)

double CAI3EM3t(double w, double s6, double s5) {
	return (pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*(-XCA0(w,s6,0,0,0) + XCA0(w,s6,s5,0,0)))/8.;
}

double CAI3EM2t(double w, double s6, double s5) {
	return (pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*((2*log(s5) - log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),0,0,0,0)))*
	        XCA0(w,s6,0,0,0) + (-2*log(s5) + log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*
	        XCA0(w,s6,s5,0,0) - XCA1(w,s6,0,0,0) + XCA1(w,s6,s5,0,0)))/8.;
}

double CAI3EM1t(double w, double s6, double s5) {
	return (pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*(-2*(-(log(s5)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))) +
	          pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*
	        XCA0(w,s6,0,0,0) + 2*(-(log(s5)*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))) +
	          pow(log(s5),2) + pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) +
	          pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*XCA0(w,s6,s5,0,0) + 2*log(s5)*XCA1(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) -
	       log(FA2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - log(FB1(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - log(FB2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - 2*log(s5)*XCA1(w,s6,s5,0,0) +
	       log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA1(w,s6,s5,0,0) + log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA1(w,s6,s5,0,0) + log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA1(w,s6,s5,0,0) +
	       log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA1(w,s6,s5,0,0) - XCA2(w,s6,0,0,0) + XCA2(w,s6,s5,0,0)))/8.;
}

double CAI3E0t(double w, double s6, double s5) {
	return (pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*(2*(-3*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*pow(log(s5),2) +
	          2*pow(log(s5),3) + 6*log(s5)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) +
	             pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)) - 4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) +
	             pow(log(FB2(v(w),tl(s6),0,0,0,0)),3)))*XCA0(w,s6,0,0,0) + 2*(3*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) +
	             log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*pow(log(s5),2) - 2*pow(log(s5),3) -
	          6*log(s5)*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) +
	             pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2)) + 4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),3) +
	             pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),3)))*XCA0(w,s6,s5,0,0) -
	       3*(2*(-(log(s5)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))) + pow(log(s5),2) +
	             pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) -
	          2*(-(log(s5)*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))) + pow(log(s5),2) +
	             pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*
	           XCA1(w,s6,s5,0,0) - 2*log(s5)*XCA2(w,s6,0,0,0) + log(FA1(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + log(FA2(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) +
	          log(FB1(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + log(FB2(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + 2*log(s5)*XCA2(w,s6,s5,0,0) -
	          log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA2(w,s6,s5,0,0) - log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA2(w,s6,s5,0,0) - log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA2(w,s6,s5,0,0) -
	          log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA2(w,s6,s5,0,0) + XCA3(w,s6,0,0,0) - XCA3(w,s6,s5,0,0))))/24.;
}

//third integration is over u (z after rescaling)

double CAI3EM3u(double w, double s6, double z) {
	return (pow(mexp,-1)*pow(n,-1)*pow(z,-1)*(-XCA0(w,s6,0,0,0) + XCA0(w,s6,0,z,0)))/4.;
}

double CAI3EM2u(double w, double s6, double z) {
	return (pow(mexp,-1)*pow(n,-1)*pow(z,-1)*((4*log(z) - log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0) +
		       (-4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*XCA0(w,s6,0,z,0) -
		       XCA1(w,s6,0,0,0) + XCA1(w,s6,0,z,0)))/4.;
}

double CAI3EM1u(double w, double s6, double z) {
	return (pow(mexp,-1)*pow(n,-1)*pow(z,-1)*(-2*(-2*log(z)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0))) +
	          4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*
	        XCA0(w,s6,0,0,0) + 2*(-2*log(z)*(log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0))) +
	          4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) +
	          pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA0(w,s6,0,z,0) + 4*log(z)*XCA1(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) -
	       log(FA2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - log(FB1(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - log(FB2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - 4*log(z)*XCA1(w,s6,0,z,0) +
	       log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA1(w,s6,0,z,0) + log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA1(w,s6,0,z,0) + log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA1(w,s6,0,z,0) +
	       log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA1(w,s6,0,z,0) - XCA2(w,s6,0,0,0) + XCA2(w,s6,0,z,0)))/4.;
}

double CAI3E0u(double w, double s6, double z) {
	return (pow(mexp,-1)*pow(n,-1)*pow(z,-1)*(8*(-3*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*pow(log(z),2) +
	          4*pow(log(z),3) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) +
	          3*log(z)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)) -
	          pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA0(w,s6,0,0,0) - 8*(-3*(log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) +
	             log(FB2(v(w),tl(s6),0,0,u(z),0)))*pow(log(z),2) + 4*pow(log(z),3) - pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),3) - pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),3) -
	          pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),3) + 3*log(z)*(pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) +
	             pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2)) - pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),3))*XCA0(w,s6,0,z,0) -
	       3*(2*(-2*log(z)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0))) + 4*pow(log(z),2) +
	             pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) -
	          2*(-2*log(z)*(log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0))) + 4*pow(log(z),2) +
	             pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*
	           XCA1(w,s6,0,z,0) - 4*log(z)*XCA2(w,s6,0,0,0) + log(FA1(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + log(FA2(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) +
	          log(FB1(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + log(FB2(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + 4*log(z)*XCA2(w,s6,0,z,0) - log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA2(w,s6,0,z,0) -
	          log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA2(w,s6,0,z,0) - log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA2(w,s6,0,z,0) - log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA2(w,s6,0,z,0) + XCA3(w,s6,0,0,0) -
	          XCA3(w,s6,0,z,0))))/12.;
}

//third integration is over b (c after rescaling)

double CAI3EM3b(double w, double s6, double c) {
	return (pow(c,-1)*pow(mexp,-1)*pow(n,-1)*(-XCA0(w,s6,0,0,0) + XCA0(w,s6,0,0,c)))/4.;
}

double CAI3EM2b(double w, double s6, double c) {
	return (pow(c,-1)*pow(mexp,-1)*pow(n,-1)*((4*log(c) - log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0) +
		       (-4*log(c) + log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA0(w,s6,0,0,c) -
		       XCA1(w,s6,0,0,0) + XCA1(w,s6,0,0,c)))/4.;
}

double CAI3EM1b(double w, double s6, double c) {
	return (pow(c,-1)*pow(mexp,-1)*pow(n,-1)*(-2*(-2*log(c)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0))) +
	          4*pow(log(c),2) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*
	        XCA0(w,s6,0,0,0) + 2*(-2*log(c)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c)))) +
	          4*pow(log(c),2) + pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) +
	          pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XCA0(w,s6,0,0,c) + 4*log(c)*XCA1(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) -
	       log(FA2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - log(FB1(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - log(FB2(v(w),tl(s6),0,0,0,0))*XCA1(w,s6,0,0,0) - 4*log(c)*XCA1(w,s6,0,0,c) +
	       log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA1(w,s6,0,0,c) + log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA1(w,s6,0,0,c) + log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA1(w,s6,0,0,c) +
	       log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA1(w,s6,0,0,c) - XCA2(w,s6,0,0,0) + XCA2(w,s6,0,0,c)))/4.;
}

double CAI3E0b(double w, double s6, double c) {
	return (pow(c,-1)*pow(mexp,-1)*pow(n,-1)*(8*(-3*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*pow(log(c),2) +
	          4*pow(log(c),3) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) +
	          3*log(c)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)) -
	          pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA0(w,s6,0,0,0) - 8*(-3*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) +
	             log(FB2(v(w),tl(s6),0,0,0,b(c))))*pow(log(c),2) + 4*pow(log(c),3) - pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) - pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) -
	          pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + 3*log(c)*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) +
	             pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)) - pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*XCA0(w,s6,0,0,c) -
	       3*(2*(-2*log(c)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0))) + 4*pow(log(c),2) +
	             pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) -
	          2*(-2*log(c)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c)))) + 4*pow(log(c),2) +
	             pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
	           XCA1(w,s6,0,0,c) - 4*log(c)*XCA2(w,s6,0,0,0) + log(FA1(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + log(FA2(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) +
	          log(FB1(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + log(FB2(v(w),tl(s6),0,0,0,0))*XCA2(w,s6,0,0,0) + 4*log(c)*XCA2(w,s6,0,0,c) - log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA2(w,s6,0,0,c) -
	          log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA2(w,s6,0,0,c) - log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA2(w,s6,0,0,c) - log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA2(w,s6,0,0,c) + XCA3(w,s6,0,0,0) -
	          XCA3(w,s6,0,0,c))))/12.;
}

//third integration is over y (x after rescaling)

double CAI3EM3y(double w, double s6, double x) {
	return 0;
}

double CAI3EM2y(double w, double s6, double x) {
	return ((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
		       log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*pow(x,-1)*XCA0(w,s6,0,0,0))/8.;
}

double CAI3EM1y(double w, double s6, double x) {
	return (pow(x,-1)*(2*(mexp*n*log(x)*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
            log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0))) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) -
         pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) -
         pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA0(w,s6,0,0,0) +
      (log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
         log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA1(w,s6,0,0,0)))/8.;
}

double CAI3E0y(double w, double s6, double x) {
	return (pow(x,-1)*(2*(3*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
            log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*pow(mexp,2)*pow(n,2)*pow(log(x),2) +
         6*mexp*n*log(x)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) +
            pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2)) +
         4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),3) +
            pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),3)))*XCA0(w,s6,0,0,0)
        + 3*(2*(mexp*n*log(x)*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
               log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0))) + pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) -
            pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) -
            pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA1(w,s6,0,0,0) +
         (log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
            log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA2(w,s6,0,0,0))))/24.;
}
