/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement function f, plus distribution denominators 
 * and contributing remainder/numerator functions for the integration at all eps-orders of the real-virtual interference (1-particle cut) contribution to 
 * the 2-loop soft function. Unlike for the rest of the 2-loop calculation and similar to 1-loop we haven't split the 
 * computation along the dimension of the integration domain, as at most 2-dimensional integrals appear. So this computations includes also terms which 
 * strictly only depend on one variable integrated over two.
 * Example: IRVE1 ('I'ntegration for 'R'eal-'V'irtual interference, at 'E'ps to the '1'st order [M1 stands for 'M'inus '1'st]) contains various logs of the f  
 * function and other polynomials in such a way that the various logs provide enough eps factors to arrive at eps^1. Accordingly, we see below that IRVEM1 
 * contains no logs, as here one +-distribution's delta-part provides the one inverse power of eps, and all other factors are expanded to leading order only. 
 * IRVE0 contains logs of various polynomials, and of f(0,tl). f(y,tl) does not appear, as without the delta-part of the y-plus-distribution no eps-divergence  
 * would be there, and then only leading order expanded terms could appear here, i.e. no logs. IRVE1 is therefore the first term in which the full 
 * variable-dependence of f appears.
 */

#include <Auxiliaries.h>
#include <Input_Common.h>
#include <cmath>

using namespace std;

double IRVEM1(double x, double s) {
	return ((1 - s)*s*(1 + s)*pow(mexp,-1)*pow(n,-1)*(1 + pow(s,2))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/2.;
}

double IRVE0(double x, double s) {
	return ((1 - s)*s*(1 + s)*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) + 4*log(f(0,tl(s))) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*pow(mexp,-1)*pow(n,-1)*(1 + pow(s,2))*pow(2 - pow(s,4),-0.5)*
     pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/2.;
}

double IRVE1(double x, double s) {
	return ((1 - s)*s*(1 + s)*pow(mexp,-1)*pow(n,-1)*(1 + pow(s,2))*pow(x,-1)*(8*x*log(f(0,tl(s)))*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8))) + 
       16*(-(mexp*n*log(f(0,tl(s)))) + mexp*n*log(f(y(x),tl(s))) + x*pow(log(f(0,tl(s))),2)) + x*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2))*
     pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/4.;
}

double IRVE2(double x, double s) {
	return ((1 - s)*s*(1 + s)*pow(mexp,-1)*pow(n,-1)*(1 + pow(s,2))*pow(x,-1)*(-48*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*
        (mexp*n*log(f(0,tl(s))) - mexp*n*log(f(y(x),tl(s))) - x*pow(log(f(0,tl(s))),2)) + 32*(3*log(x)*(-log(f(0,tl(s))) + log(f(y(x),tl(s))))*pow(mexp,2)*pow(n,2) - 3*mexp*n*pow(log(f(0,tl(s))),2) + 2*x*pow(log(f(0,tl(s))),3) + 3*mexp*n*pow(log(f(y(x),tl(s))),2)) + 
       12*x*log(f(0,tl(s)))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2) + 
       x*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),3))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/12.;
}

double IRVE3(double x, double s) {
	return ((1 - s)*s*(1 + s)*pow(mexp,-1)*pow(n,-1)*(1 + pow(s,2))*pow(x,-1)*(-128*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*
        (3*log(x)*(log(f(0,tl(s))) - log(f(y(x),tl(s))))*pow(mexp,2)*pow(n,2) + 3*mexp*n*pow(log(f(0,tl(s))),2) - 2*x*pow(log(f(0,tl(s))),3) - 3*mexp*n*pow(log(f(y(x),tl(s))),2)) - 
       128*(3*(log(f(0,tl(s))) - log(f(y(x),tl(s))))*pow(mexp,3)*pow(n,3)*pow(log(x),2) + 4*mexp*n*pow(log(f(0,tl(s))),3) - 2*x*pow(log(f(0,tl(s))),4) + 6*log(x)*pow(mexp,2)*pow(n,2)*(pow(log(f(0,tl(s))),2) - pow(log(f(y(x),tl(s))),2)) - 
          4*mexp*n*pow(log(f(y(x),tl(s))),3)) - 96*(mexp*n*log(f(0,tl(s))) - mexp*n*log(f(y(x),tl(s))) - x*pow(log(f(0,tl(s))),2))*
        pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2) + 
       16*x*log(f(0,tl(s)))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),3) + 
       x*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),4))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/48.;
}
