/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 3D integration at all eps-orders and the alpha^0 order of the Rest-CA structure. 
 * Example: CAI3EM2s ('CA' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd and alpha^0 order, third integration over 's'5) 
 * contains various differences of logs of FXi functions evaluated at z=0,c=0,x=0, i.e. with deltas from all +-distributions except the t5/s5 one, multiplied 
 * with the correct XCA functions to arrive at eps^-2 alpha^0. 
 */

#include <3IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>
using namespace std;

//third integration is over t5 (s5 after rescaling)

double CAI3EM3s(double w, double s6, double s5) {
	return 0.;
}

double CAI3EM2s(double w, double s6, double s5) {
	return (pow(s5,-1)*(-((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0)) + 
       (log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA0(w,s6,s5,0,0)))/8.;
}

double CAI3EM1s(double w, double s6, double s5) {
	return (pow(s5,-1)*(2*log(s5)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0) - 
       4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
       2*log(s5)*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA0(w,s6,s5,0,0) + 
       4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*XCA0(w,s6,s5,0,0) - 
       (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0) + 
       (log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA1(w,s6,s5,0,0)))/8.;
}

double CAI3E0s(double w, double s6, double s5) {
	return (pow(s5,-1)*(-2*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*pow(log(s5),2)*XCA0(w,s6,0,0,0) + 
       8*log(s5)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
       8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA0(w,s6,0,0,0) + 
       2*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*pow(log(s5),2)*XCA0(w,s6,s5,0,0) - 
       8*log(s5)*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*XCA0(w,s6,s5,0,0) + 
       8*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),3) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),3))*XCA0(w,s6,s5,0,0) + 
       2*log(s5)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0) - 
       4*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) - 
       2*log(s5)*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA1(w,s6,s5,0,0) + 
       4*(pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2))*XCA1(w,s6,s5,0,0) - 
       (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA2(w,s6,0,0,0) + 
       (log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)))*XCA2(w,s6,s5,0,0)))/8.;
}

//third integration is over u (z after rescaling)

double CAI3EM3z(double w, double s6, double z) {
	return 0.;
}

double CAI3EM2z(double w, double s6, double z) {
	return (pow(z,-1)*(-((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0)) + 
       (log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*XCA0(w,s6,0,z,0)))/4.;
}

double CAI3EM1z(double w, double s6, double z) {
	return pow(z,-1)*(log(z)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0) - 
     (pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
     log(z)*(log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*XCA0(w,s6,0,z,0) + 
     (pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA0(w,s6,0,z,0) - 
     ((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0))/4. + 
     ((log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*XCA1(w,s6,0,z,0))/4.);
}

double CAI3E0z(double w, double s6, double z) {
	return pow(z,-1)*(-2*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*pow(log(z),2)*XCA0(w,s6,0,0,0) + 
     4*log(z)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
     2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA0(w,s6,0,0,0) + 
     2*(log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*pow(log(z),2)*XCA0(w,s6,0,z,0) - 
     4*log(z)*(pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA0(w,s6,0,z,0) + 
     2*(pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),3) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),3) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),3) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),3))*XCA0(w,s6,0,z,0) + 
     log(z)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0) - 
     (pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) - 
     log(z)*(log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*XCA1(w,s6,0,z,0) + 
     (pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA1(w,s6,0,z,0) - 
     ((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA2(w,s6,0,0,0))/4. + 
     ((log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FB1(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)))*XCA2(w,s6,0,z,0))/4.);
}

//third integration is over b (c after rescaling)

double CAI3EM3c(double w, double s6, double c) {
	return 0;
}

double CAI3EM2c(double w, double s6, double c) {
	return (pow(c,-1)*(-((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0)) + 
       (log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA0(w,s6,0,0,c)))/4.;
}

double CAI3EM1c(double w, double s6, double c) {
	return pow(c,-1)*(log(c)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA0(w,s6,0,0,0) - 
     (pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
     log(c)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA0(w,s6,0,0,c) + 
     (pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XCA0(w,s6,0,0,c) - 
     ((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0))/4. + 
     ((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA1(w,s6,0,0,c))/4.);
}

double CAI3E0c(double w, double s6, double c) {
	return pow(c,-1)*(-2*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*pow(log(c),2)*XCA0(w,s6,0,0,0) + 
     4*log(c)*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA0(w,s6,0,0,0) - 
     2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA0(w,s6,0,0,0) + 
     2*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*pow(log(c),2)*XCA0(w,s6,0,0,c) - 
     4*log(c)*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XCA0(w,s6,0,0,c) + 
     2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*XCA0(w,s6,0,0,c) + 
     log(c)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA1(w,s6,0,0,0) - 
     (pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA1(w,s6,0,0,0) - 
     log(c)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA1(w,s6,0,0,c) + 
     (pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XCA1(w,s6,0,0,c) - 
     ((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA2(w,s6,0,0,0))/4. + 
     ((log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA2(w,s6,0,0,c))/4.);
}

//third integration is over y (x after rescaling)

double CAI3EM3x(double w, double s6, double x) {
	return 0;
}

double CAI3EM2x(double w, double s6, double x) {
	return (mexp*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + 
       log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*pow(x,-1)*XCA0(w,s6,0,0,0))/8.;
}

double CAI3EM1x(double w, double s6, double x) {
	return (mexp*pow(x,-1)*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) + 
          pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA0(w,s6,0,0,0) + 
       (log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + 
          log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA1(w,s6,0,0,0)))/8.;
}

double CAI3E0x(double w, double s6, double x) {
	return (mexp*pow(x,-1)*(8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),3) + 
          pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),3))*XCA0(w,s6,0,0,0) + 
       6*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) - 
          pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA1(w,s6,0,0,0) + 
       3*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + 
          log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA2(w,s6,0,0,0)))/24.;
}
