/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement function f, plus distribution denominators 
 * and contributing remainder/numerator functions for the integration at all regulator-orders of the real-virtual interference (1-particle cut) contribution to 
 * the 2-loop soft function. Unlike for the rest of the 2-loop calculation and similar to 1-loop we haven't split the 
 * computation along the dimension of the integration domain, as at most 2-dimensional integrals appear. So this computations includes also terms which 
 * strictly only depend on one variable, integrated over two.
 * Example: IRVA1E1 ('I'ntegration for 'R'eal-'V'irtual interference, at 'A'lpha to the '1'st order and 'E'ps to the '1'st order [M1 stands for 'M'inus '1'st]) 
 * contains various logs of the f function and other polynomials in such a way that the various logs provide enough regulator factors to arrive at eps^1 alpha^1. Accordingly, 
 * we see below that IRVAM1E0 contains no logs, as here one +-distribution's delta-part provides the one inverse power of alpha, and all other factors are expanded 
 * to leading order only. IRVA0E0 contains logs of f(0,tl). f(y,tl) does not appear, as without the delta-part of the y-plus-distribution
 * eps-divergence would be there, and then only leading order expanded terms could appear here, i.e. no logs. IRVA0E1 is therefore the first term in which the full 
 * variable-dependence of f appears.
 */

#include <Auxiliaries.h>
#include <cmath>
#include <Input_Common.h>

using namespace std;

double IRVA0E0(double x, double s) {
	return 2*(1 - s)*s*(1 + s)*log(f(0,tl(s)))*(1 + pow(s,2))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5);
}

double IRVA0E1(double x, double s) {
	return -((1 - s)*s*(1 + s)*(1 + pow(s,2))*pow(x,-1)*(4*mexp*log(f(0,tl(s))) - 4*mexp*log(f(y(x),tl(s))) - 
       2*x*log(f(0,tl(s)))*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8))) - 8*x*pow(log(f(0,tl(s))),2))*pow(2 - pow(s,4),-0.5)*
     pow(2 - 2*pow(s,4) + pow(s,8),-0.5));
}

double IRVA0E2(double x, double s) {
	return -((1 - s)*s*(1 + s)*(1 + pow(s,2))*pow(x,-1)*(8*mexp*pow(log(f(0,tl(s))),2) + (-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*
        (4*mexp*log(f(0,tl(s))) - 4*mexp*log(f(y(x),tl(s))) - 8*x*pow(log(f(0,tl(s))),2)) - 16*x*pow(log(f(0,tl(s))),3) - 8*mexp*pow(log(f(y(x),tl(s))),2) - 
       x*log(f(0,tl(s)))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5));
}

double IRVA0E3(double x, double s) {
	return -((1 - s)*s*(1 + s)*(1 + pow(s,2))*pow(x,-1)*((-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*
        (8*mexp*pow(log(f(0,tl(s))),2) - 16*x*pow(log(f(0,tl(s))),3) - 8*mexp*pow(log(f(y(x),tl(s))),2)) + (32*(mexp*pow(log(f(0,tl(s))),3) - 2*x*pow(log(f(0,tl(s))),4) - mexp*pow(log(f(y(x),tl(s))),3)))/3. + 
       ((4*mexp*log(f(0,tl(s))) - 4*mexp*log(f(y(x),tl(s))) - 8*x*pow(log(f(0,tl(s))),2))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2))/2. - 
       (x*log(f(0,tl(s)))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),3))/3.)*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5));
}


double IRVAM1E0(double x, double s) {
	return 2*(1 - s)*s*(1 + s)*(1 + pow(s,2))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5);
}
double IRVAM1E1(double x, double s) {
	return 2*(1 - s)*s*(1 + s)*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) + 4*log(f(0,tl(s))) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*(1 + pow(s,2))*pow(2 - pow(s,4),-0.5)*
   pow(2 - 2*pow(s,4) + pow(s,8),-0.5);
}
double IRVAM1E2(double x, double s) {
	return (1 - s)*s*(1 + s)*(1 + pow(s,2))*(8*log(f(0,tl(s)))*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8))) + 16*pow(log(f(0,tl(s))),2) + 
     pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5);
}
double IRVAM1E3(double x, double s) {
	return ((1 - s)*s*(1 + s)*(1 + pow(s,2))*(48*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*pow(log(f(0,tl(s))),2) + 64*pow(log(f(0,tl(s))),3) + 
       12*log(f(0,tl(s)))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2) + 
       pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),3))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/3.;
}
double IRVAM1E4(double x, double s) {
	return ((1 - s)*s*(1 + s)*(1 + pow(s,2))*(256*(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)))*pow(log(f(0,tl(s))),3) + 256*pow(log(f(0,tl(s))),4) + 
       96*pow(log(f(0,tl(s))),2)*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),2) + 
       16*log(f(0,tl(s)))*pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),3) + 
       pow(-4*log(1 - s) - 4*log(s) - 4*log(1 + s) - 4*log(1 + pow(s,2)) - log(2 - pow(s,4)) - log(2 - 2*pow(s,4) + pow(s,8)),4))*pow(2 - pow(s,4),-0.5)*pow(2 - 2*pow(s,4) + pow(s,8),-0.5))/12.;
}
